/**************************************************************************
*  Copyright (c) 2013-2014 by Michael Fischer.
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  31.12.2013  mifi  First Version
**************************************************************************/
#define __THREAD_C__

/*=======================================================================*/
/*  Include                                                              */
/*=======================================================================*/
#include <stdlib.h>
#include <string.h>
#include <stdint.h>
#include "tal.h"

extern void NutTcpSm (void *arg);
extern void NutDhcpClient (void *arg);

/*=======================================================================*/
/*  All Structures and Common Constants                                  */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all local Data                                         */
/*=======================================================================*/

/*
 * This is the tcb and stack for the ReceiverTask
 */
static OS_STACK (tcpsm_stack, TASK_IP_SM_STK_SIZE);
static os_tcb_t tcb_tcpsm;

/*
 * This is the tcb and stack for the NutDhcpClient
 */
static OS_STACK (dhcp_stack, TASK_IP_DHCPC_STK_SIZE);
static os_tcb_t tcb_dhcp;

/*=======================================================================*/
/*  Definition of all local Procedures                                   */
/*=======================================================================*/

/*=======================================================================*/
/*  All code exported                                                    */
/*=======================================================================*/

/*************************************************************************/
/*  NutThreadSetPriority                                                 */
/*                                                                       */
/*  Set the current thread's priority.                                   */
/*                                                                       */
/*  In    : new priotity                                                 */
/*  Out   : none                                                         */
/*  Return: old priority                                                 */
/*************************************************************************/
uint8_t NutThreadSetPriority (uint8_t level)
{
   return( (uint8_t)OSTaskChangePriority(level) );
} /* NutThreadSetPriority */

/*************************************************************************/
/*  NutThreadYield                                                       */
/*                                                                       */
/*  Give up the CPU.                                                     */
/*                                                                       */
/*  In    : none                                                         */
/*  Out   : none                                                         */
/*  Return: none                                                         */
/*************************************************************************/
void NutThreadYield (void)
{
   OSTaskYield();
} /* NutThreadYield */

/*************************************************************************/
/*  NutThreadCreate                                                      */
/*                                                                       */
/*  Create a new thread.                                                 */
/*                                                                       */
/*  In    : name, fn, arg, stackSize                                     */
/*  Out   : none                                                         */
/*  Return: Pointer to the TCB structure or 0 to indicate an error       */
/*************************************************************************/
void *NutThreadCreate (char *name, void (*fn) (void *), void *arg, size_t stackSize)
{   
   (void)stackSize;

   if (fn == NutTcpSm)
   {
      if (OS_TASK_STATE_NOT_IN_USE == tcb_tcpsm.State)
      {
         OSTaskCreate(&tcb_tcpsm, fn, arg, TASK_IP_SM_PRIORITY, tcpsm_stack, sizeof(tcpsm_stack), name);
      }   
      
      return((void*)&tcb_tcpsm);
   }
   else if (fn == NutDhcpClient)
   {
      if (OS_TASK_STATE_NOT_IN_USE == tcb_dhcp.State)
      {
         OSTaskCreate(&tcb_dhcp, fn, arg, TASK_IP_DHCPC_PRIORITY, dhcp_stack, sizeof(dhcp_stack), name);
      }   
      
      return((void*)&tcb_dhcp);
   }
   
   return(NULL);
}

/*************************************************************************/
/*  NutThreadExit                                                        */
/*                                                                       */
/*  End the current thread.                                              */
/*                                                                       */
/*  In    : none                                                         */
/*  Out   : none                                                         */
/*  Return: none                                                         */
/*************************************************************************/
void NutThreadExit (void)
{
   OSTaskExit();
}

/*** EOF ***/
