/**************************************************************************
*  Copyright (c) 2013-2014 by Michael Fischer.
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  31.12.2013  mifi  First Version
**************************************************************************/
#define __TIMER_C__

/*=======================================================================*/
/*  Include                                                              */
/*=======================================================================*/
#include <stdint.h>
#include "tal.h"
#include "tcts.h"

/*=======================================================================*/
/*  All Structures and Common Constants                                  */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all local Data                                         */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all local Procedures                                   */
/*=======================================================================*/

/*=======================================================================*/
/*  All code exported                                                    */
/*=======================================================================*/

/*************************************************************************/
/*  NutGetSeconds                                                        */
/*                                                                       */
/*  Return the seconds counter value.                                    */
/*                                                                       */
/*  In    : none                                                         */
/*  Out   : none                                                         */
/*  Return: sec time                                                     */
/*************************************************************************/
uint32_t NutGetSeconds (void)
{
   return( OSTimeGetSeconds() );
} /* NutGetSeconds */

/*************************************************************************/
/*  NutGetMillis                                                         */
/*                                                                       */
/*  Return the milliseconds counter value.                               */
/*                                                                       */
/*  In    : none                                                         */
/*  Out   : none                                                         */
/*  Return: millisec time                                                */
/*************************************************************************/
uint32_t NutGetMillis (void)
{
   return( OSTimeGet() );
} /* NutGetMillis */

/*************************************************************************/
/*  NutGetTickCount                                                      */
/*                                                                       */
/*  Return the number of system timer ticks.                             */
/*                                                                       */
/*  In    : none                                                         */
/*  Out   : none                                                         */
/*  Return: tick counter                                                 */
/*************************************************************************/
uint32_t NutGetTickCount (void)
{
   return( OSTimeGet() );
} /* NutGetTickCount */

/*************************************************************************/
/*  NutSleep                                                             */
/*                                                                       */
/*  Temporarily suspends the current thread.                             */
/*                                                                       */
/*  In    : ms                                                           */
/*  Out   : none                                                         */
/*  Return: none                                                         */
/*************************************************************************/
void NutSleep (uint32_t ms)
{
   OSTimeDly(ms);
} /* NutSleep */

/*************************************************************************/
/*  NutDelay                                                             */
/*                                                                       */
/*  Loop for a specified number of milliseconds,                         */
/*  will not release the CPU.                                            */
/*                                                                       */
/*  In    : ms                                                           */
/*  Out   : none                                                         */
/*  Return: none                                                         */
/*************************************************************************/
void NutDelay (uint32_t ms)
{
   OSTimeWait(ms);
} /* NutDelay */

/*** EOF ***/
